@@ -1,35 +1,35 @@
 package Struct::Match;
-use 5.006; use strict; use warnings; no warnings qw(void); use utf8; our $VERSION = '0.05';
-use Combine::Keys qw/combine_keys/; 
+use 5.006; use strict; use warnings; no warnings qw(void); use utf8; our $VERSION = '0.07';
+use Combine::Keys qw/combine_keys/;
 use base 'Import::Export';
-our %STRUCT; 
-our %EX = ('match' => ['all'], '%STRUCT' => ['struct', 'all']); 
+our %STRUCT;
+our %EX = ('match' => ['all'], '%STRUCT' => ['struct', 'all']);
 
 BEGIN {
 	%STRUCT = (
-		SCALAR => sub { 
-			$STRUCT{SAME}($_[1], 'SCALAR') 
-				and do { 
-					my $s = quotemeta($_[1]); 
+		SCALAR => sub {
+			$STRUCT{SAME}($_[1], 'SCALAR')
+				and do {
+					my $s = quotemeta($_[1]);
 					$_[0] =~ m†^($s)$†;
 				};
 		},
 		HASH => sub {
 			$STRUCT{SAME}($_[1], 'HASH')
-				and ! $STRUCT{ADDR}($_[0], $_[1]) 
+				and ! $STRUCT{ADDR}($_[0], $_[1])
 					? do {
-						exists $_[0]->{$_} && exists $_[1]->{$_} && match($_[0]->{$_}, $_[1]->{$_}) 
-							or return for combine_keys($_[0], $_[1]); 
+						exists $_[0]->{$_} && exists $_[1]->{$_} && match($_[0]->{$_}, $_[1]->{$_})
+							or return for combine_keys($_[0], $_[1]);
 						1;
 					}
-					: 1;				
+					: 1;
 		},
 		ARRAY => sub {
-			$STRUCT{SAME}($_[1], 'ARRAY') 
-				and ! $STRUCT{ADDR}($_[0], $_[1]) 
+			$STRUCT{SAME}($_[1], 'ARRAY')
+				and ! $STRUCT{ADDR}($_[0], $_[1])
 					? (((
-							grep { 
-								exists $_[0][$_] && match($_[0][$_], $_[1][$_]) 
+							grep {
+								exists $_[0][$_] && match($_[0][$_], $_[1][$_])
 							} 0 .. $#{$_[1]}
 						) == @{$_[0]}
 					) && $#{$_[0]} == $#{$_[1]})
@@ -39,24 +39,24 @@ BEGIN {
 			0 + $_[0] == 0 + $_[1];
 		}, # thou shall not pass/work if the object has + overloaded
 		CHECK => sub {
-			my $t = $STRUCT{REFTYPE}($_[0]); 
+			my $t = $STRUCT{REFTYPE}($_[0]);
 			$STRUCT{SAME}($_[1], $t) && $STRUCT{$t}($_[0], $_[1]);
 		},
 		REFTYPE => sub {
-			eval { $_[0]->[0] } 
-				? 'ARRAY' 
-				: eval { $_[0]->{shamed}; 1 } 
-						? 'HASH' 
+			eval { $_[0]->[0] }
+				? 'ARRAY'
+				: eval { $_[0]->{shamed}; 1 }
+						? 'HASH'
 						: 'ADDR';
 		},
-		REF => sub { 
-			my $r = ref($_[0]); 
-			$r and ((exists $STRUCT{$r} && $r) || 'CHECK') or 'SCALAR'; 
+		REF => sub {
+			my $r = ref($_[0]);
+			$r and ((exists $STRUCT{$r} && $r) || 'CHECK') or 'SCALAR';
 		},
-		SAME => sub { 
-			my $s = $STRUCT{REF}($_[0]); 
-			$s eq 'CHECK' && do { $s = $STRUCT{REFTYPE}($_[0]) }; 
-			$s eq $_[1]; 
+		SAME => sub {
+			my $s = $STRUCT{REF}($_[0]);
+			$s eq 'CHECK' && do { $s = $STRUCT{REFTYPE}($_[0]) };
+			$s eq $_[1];
 		},
 		# currently we do not care about CODE|GLOB|REF|LVALUE|FORMAT|IO|VSTRING|Regexp.. other than doing ref address check hushh
 	);
@@ -72,7 +72,7 @@ Struct::Match - Exact Match (SCALAR|HASH|ARRAY)'s.
 
 =head1 VERSION
 
-Version 0.05
+Version 0.07
 
 =cut
 
@@ -86,14 +86,30 @@ Version 0.05
 
 =head2 Upsetting
 
-Currently when passed a CODE|GLOB|REF|LVALUE|FORMAT|IO|VSTRING|Regexp match will likely return false. unless you pass a third parameter to bypass this. 
+Currently when passed a CODE|GLOB|REF|LVALUE|FORMAT|IO|VSTRING|Regexp match will likely return false. unless you pass a third parameter to bypass this.
 
 =cut
 
 =head2 match
 
+Accepts two variables and checks whether they match. Is $variable1 == $variable2 if true then this function returns 1 if false then this function will return 0.
+
 =cut
 
+=head1 extending
+
+Sometimes you may need custom match behaviour or will want to expand to handle more than just (SCALAR|HASH|ARRAY)'s, to do this you can simply import and append the %STRUCT variable.
+
+	package Custom::Match;
+	use Struct::Match qw/struct/;
+
+	BEGIN {
+		@STRUCT{qw/Regexp CODE/} = (
+			sub { $_[1] =~ $_[0]; },
+			sub { my $v = eval { $_[0]->($_[1]) }; }
+		);
+	}
+
 =head1 AUTHOR
 
 LNATION, C<< <thisusedtobeanemail at gmail.com> >>
